@@ -9,7 +9,6 @@ load("coreclr")
 import clr, pathlib
 
 CURRENT_DIR = pathlib.Path(__file__).parent.resolve()
-print(f"CurDir: {CURRENT_DIR}")
 ANIMO_UNITY_DLL_DIR = os.path.realpath(os.path.join(CURRENT_DIR, "lib"))
 
 # Load Animo DLLs
@@ -32,6 +31,12 @@ parser = argparse.ArgumentParser()
 parser.add_argument(
     "training_session_full_path", nargs="?", default=None
 )
+parser.add_argument(
+    "--daemon",
+    type=int,
+    default=None,
+    help="Parent process id. If process dead at checkpoint the training will be interrupted",
+)
 
 
 def main():
@@ -39,11 +44,13 @@ def main():
 
     register_trainer_plugins()
     
-    training_session_folder_path = parser.parse_args().training_session_full_path
+    parsed_args = parser.parse_args()
+
+    training_session_folder_path = parsed_args.training_session_full_path
     if training_session_folder_path is None:
         raise ValueError("Training session full path must be provided")
     
-    training_session_data = AnimoTrainingSession(training_session_folder_path)
+    training_session_data = AnimoTrainingSession(training_session_folder_path, parsed_args.daemon)
 
     register_animo_stats_writers(training_session_data.run_options)
     
